@@ -182,7 +182,7 @@ class ConfigCmd:
 
         self.n_users_per_round = 100
         if self._xml_input.findall('simulator/n-users-per-round'):
-            self.n_user_per_round = int(self._xml_input.findall('simulator/n-users-per-round')[0].text)
+            self.n_users_per_round = int(self._xml_input.findall('simulator/n-users-per-round')[0].text)
 
         self.delayed_update = False
         if self._xml_input.findall('simulator/delayed-update'):
